@@ -1,20 +1,17 @@
-# Copyright 2024 Minwoo(Daniel) Park, MIT License
+# Copyright 2024 Daniel Park, Antonio Cheang, MIT License
 from os import environ
-from gemini.core import Gemini, GeminiSession
+from gemini.core import Gemini
 from gemini.constants import (
     HEADERS,
-    ALLOWED_LANGUAGES,
-    DEFAULT_LANGUAGE,
     REPLIT_SUPPORT_PROGRAM_LANGUAGES,
-    REQUIRED_COOKIE_LIST,
     Tool,
 )
 from gemini.client import GeminiClient
 from gemini.utils import (
-    extract_links,
-    upload_image,
     max_token,
     max_sentence,
+    build_replit_data,
+    extract_code
 )
 
 gemini_api_key = environ.get("GEMINI_COOKIES")
@@ -22,17 +19,15 @@ gemini_api_key = environ.get("GEMINI_COOKIES")
 __all__ = [
     "GeminiClient",
     "Gemini",
-    "GeminiSession",
-    "extract_links",
-    "upload_image",
     "max_token",
     "max_sentence",
-    "DEFAULT_LANGUAGE",
     "HEADERS",
-    "ALLOWED_LANGUAGES",
     "REPLIT_SUPPORT_PROGRAM_LANGUAGES",
-    "REQUIRED_COOKIE_LIST",
     "Tool",
+    "build_replit_data",
+    "extract_code",
 ]
-__version__ = "0.1.3"
-__author__ = "daniel park <parkminwoo1991@gmail.com>"
+__version__ = "1.0.3"
+__author__ = (
+    "daniel park <parkminwoo1991@gmail.com>, antonio cheang <teapotv8@proton.me>"
+)
